@@ -895,131 +895,131 @@ structure(list(NA_real_, NA_real_, k3 = c(0.166666666666667,
 "k6", "k7", "k8", "k9", "k10", "k11", "k12", "k13", "k14", "k15"
 ))
 .Random.seed <-
-c(403L, 10L, -1793453778L, -119326503L, -1173310741L, 968908634L, 
-78285084L, -895942625L, -1293554571L, 1991293196L, 1199740130L, 
--610878019L, 1330571831L, 293525726L, -1914465256L, 2067180411L, 
-1785314073L, -1798346840L, 1134012246L, -240910383L, 1275648899L, 
--424370670L, 1420491172L, 365387111L, -878861635L, -539401676L, 
-932469146L, 353404389L, -1879719553L, 1097345286L, -1102810480L, 
-1739068211L, -2117154607L, 1078045312L, -1021396130L, 307628201L, 
-1135856475L, 1201002858L, 338676748L, 1207364687L, -1432011515L, 
-1066024380L, -363587438L, 557955981L, -1056146489L, -1392729938L, 
-401109256L, 1396649739L, -801891863L, -469295432L, 1199999334L, 
--1485747711L, -1086700397L, -1026711742L, -1628729100L, -756462345L, 
-490620141L, -2000341116L, 2144291242L, 1979674389L, 2093444527L, 
-734590390L, -1015387168L, 1276076835L, 641827905L, 1741952816L, 
--321448626L, -357066823L, 1352913355L, 1424773754L, 572102524L, 
--495986753L, 272375957L, -12767572L, 1225579650L, 809561181L, 
-1627829079L, 2045333054L, -56786312L, -10292901L, 1684086969L, 
--907333368L, 1866286006L, -1723367183L, 2022897443L, 1023971698L, 
--213179452L, -473149561L, -114248355L, 501508948L, 1245909370L, 
--243393339L, -1914274273L, 406018470L, -459367632L, -528320045L, 
-1983512561L, 538134816L, -71075906L, -488859703L, 638302075L, 
-822537546L, 639240620L, -1675369297L, 605281893L, 1099253276L, 
-773101682L, -362389779L, 1089651495L, 1145757518L, -997959768L, 
--2143394901L, -2105253687L, 505899224L, -199567994L, -823079839L, 
--2131542541L, 189021282L, -848201004L, -867415081L, 2137948621L, 
-601757028L, 1487593802L, 872220853L, 285483023L, -109405930L, 
-204145600L, 905219971L, 1625963937L, -199597680L, -746214802L, 
-424676377L, 1537511595L, -867797862L, 1845167196L, 1387200863L, 
-1555669813L, 958555852L, 1091138594L, 2055456381L, 1296948087L, 
-1156568222L, -1172991144L, -1174661445L, -918439847L, -1619530776L, 
--604361194L, 309784977L, 1252598339L, -154328750L, 751711716L, 
-190487591L, 1136978045L, 1783969140L, 73513306L, 1402646437L, 
--782544961L, 192676934L, -1871633712L, -1638191885L, -1646556655L, 
-508873792L, 115171358L, -918716695L, 798276635L, 285987882L, 
--973822132L, -88220401L, 1658847301L, 1572612604L, 1514874962L, 
-355717581L, 1792553863L, 614831726L, 42767944L, 792227915L, 378542505L, 
-273716472L, -1802641370L, -874041023L, 608947923L, -1449036158L, 
-1932393652L, -388709321L, 1714071341L, 336307268L, -504624790L, 
-1415914965L, 1343554415L, -764994954L, -565224032L, 1406782051L, 
-1086184193L, 522719856L, -1409593842L, -198179207L, 2078945803L, 
-1938467642L, 3592764L, 1395888511L, 1820211925L, 452958956L, 
-1273474114L, -1009532003L, 2056149527L, 731979646L, -1357009608L, 
--265369061L, -1072295047L, -932796984L, 1421040118L, 1764805681L, 
--297005469L, -1908436430L, 2138709892L, 1768418759L, 1242244253L, 
--684645356L, 868975290L, 68403973L, -1461061409L, -1391713946L, 
--1118935824L, 1373433875L, 476263857L, -382939040L, -715162114L, 
--1131124343L, 78151355L, -1137507444L, 2140384700L, -1614046158L, 
--2139723968L, 719422644L, 1021495112L, -1493906758L, -1204052208L, 
-508148972L, 576439380L, 496930578L, -1017202784L, -279686196L, 
--937766048L, 201491650L, 943494696L, 1047729580L, 144657212L, 
-2115549042L, 639391536L, 1897657892L, -1327692744L, -249782054L, 
-772076944L, 448346876L, -1831668844L, -187451582L, -1872077312L, 
--1159338436L, -2143524272L, -1572448606L, -1683184824L, -1234415092L, 
--949045028L, 814774866L, -1442426752L, 793103188L, -480180760L, 
--482640134L, -1481774256L, -351474644L, -181491340L, -1605159278L, 
-1751592544L, 818505356L, -1862133920L, -1699726622L, 967651496L, 
-1352645836L, 48914940L, -485736526L, 214395376L, -1908873788L, 
-546945880L, 1868312442L, 1376802224L, 1351357884L, -867957676L, 
-1359677378L, -1975154912L, -1824932932L, -583444912L, 1791412706L, 
--902703768L, -810939060L, 786003196L, 1080662770L, -823278848L, 
-615730804L, 1740264456L, 1545263546L, 155087824L, 1011795436L, 
--202461292L, 605683410L, -563860896L, -1913995956L, 260899104L, 
-1769651842L, 1417819624L, 1134121964L, 616602172L, 1146246770L, 
--1413256336L, -431582940L, 975790648L, -711599718L, -685118000L, 
-88718780L, 728679572L, -1383135102L, -2027086400L, -1693024452L, 
-1102442640L, 1276341026L, -345957880L, -701437684L, 839072156L, 
-173099538L, -919986304L, 1164151572L, 1401049384L, 1541707834L, 
--1787241520L, 1671827052L, 1825657396L, 1710139026L, -1814114976L, 
--1910347444L, 771957728L, -1585851998L, -491038296L, -802449780L, 
-1763462588L, -1530273166L, -1917645840L, -1380273596L, 833228888L, 
-1610122298L, -2035157904L, 1996862524L, -960375532L, 739097282L, 
-405305056L, 444058748L, -2107188528L, 903104930L, 267967528L, 
--1241000180L, -1486430788L, 1657100082L, 658923200L, 918093876L, 
--1176928568L, 870484154L, -655494512L, 970923756L, -1301902764L, 
-1664044690L, -1584083680L, -879786548L, 48840416L, -474487614L, 
-1088969768L, -493427796L, -617386308L, 1670911986L, 1578592816L, 
-884442020L, -1347805768L, 675602266L, -50487152L, 238874492L, 
--1429080812L, -488400574L, -1231506176L, -1629834820L, 236852560L, 
--1319804638L, -590704056L, 906548236L, 2037240412L, 519968210L, 
--1362014720L, -393938604L, 376437992L, 1753131258L, -1125561648L, 
-546488108L, -933833484L, 2032528786L, -116670112L, 431116300L, 
--1314195232L, 1967228514L, -90349400L, -1433448372L, 1768499068L, 
-1281649970L, 1307602544L, 632194884L, 1096358872L, 1989846906L, 
--2142723024L, -1884510276L, -1930474924L, 714483778L, 604534432L, 
--2043776324L, -1367187504L, 878322018L, -1711461656L, -1486746420L, 
-215546364L, 803967474L, -736171904L, 256269812L, -301766008L, 
-1148421946L, -2141056688L, 1712304236L, 1923192212L, 1953784914L, 
--2089029152L, -576855860L, 1803659936L, -1236440702L, 1981099240L, 
-1294840556L, -243996356L, -309451662L, 530099824L, 1412367908L, 
--1350698952L, 863651098L, 1836867792L, 860806460L, -852082796L, 
--442667134L, 2104328128L, -1540897220L, -1854670448L, 360092706L, 
-826128648L, -1641655156L, 1695425308L, 1645922450L, 599736454L, 
-322778308L, 969986549L, -2088629153L, -1935642952L, 2127511446L, 
-850261411L, -1504171675L, -606928766L, 2047961584L, -1462476903L, 
--1291757173L, 1011352700L, -2114474326L, -716125985L, 1548246633L, 
--2138370946L, 1439024236L, -854862659L, 319556999L, -2055624336L, 
--863343602L, 40575291L, 1084091933L, -247483702L, -10347032L, 
-1822180049L, -1182155069L, 1565177284L, -1776483726L, 677575495L, 
--291159279L, 1992478358L, -503790604L, -1401852539L, -1432821553L, 
--937735736L, -1632229274L, 1511947923L, -1595167243L, 428191698L, 
--1767420896L, 574516745L, 768464699L, -667968884L, -208109798L, 
-919949711L, 1098796761L, -1263537810L, 1779809532L, 1243117165L, 
-874480151L, 1655109600L, 310080446L, -85978741L, 2012013069L, 
--1309401542L, -345565576L, -114393567L, -1269092141L, 1339207668L, 
--1241208702L, -156647145L, -1700595743L, 2008949030L, 2051883044L, 
--1353424171L, -1464512897L, -1137950952L, 448130614L, -1453776701L, 
-496213253L, -1233623902L, -1832428912L, -669047239L, -1905477909L, 
-931227612L, 1121757706L, -885834497L, 568883529L, -499815714L, 
-1685166220L, -792137635L, -1949008281L, 216739728L, 830137262L, 
-496241243L, -696089027L, -1427343190L, 1724041544L, 1238433137L, 
--708887837L, 808964580L, 516889874L, -199618329L, -1145346383L, 
-1530666230L, 907083540L, -1742006235L, -364634833L, -1417596184L, 
-1635897286L, -670403981L, -1025608491L, -1395861838L, 952602240L, 
--523110807L, -1667622181L, 1207625260L, 1740400186L, 853565679L, 
--1233228935L, 1366059022L, 633753052L, 557219405L, -509223497L, 
-968897344L, 1937736222L, -381057813L, -1828664211L, -1192399654L, 
--1711917928L, -1027951871L, 1109547187L, -810863660L, -538775838L, 
--1586843785L, 479408833L, 410403398L, -538448508L, -2066509003L, 
-728584479L, -1852262280L, -586701482L, -1714365469L, -3050075L, 
--446867390L, -950397392L, -335958439L, -926980149L, 1209530428L, 
-1868957290L, 1084628127L, 395865385L, 332077502L, -1328170836L, 
--866607619L, 1513309511L, -77251024L, -2093029554L, -833807493L, 
--2132296483L, -2020487926L, -1520207832L, 193465489L, -607487869L, 
-177420676L, 1746651058L, 2031913223L, -1491473583L, -1315480874L, 
-1378198452L, -817538107L, -1274348785L, 1857849736L, 1705151654L, 
--1410139053L, -1668137547L, -959859950L, -2099520413L)
+c(403L, 10L, 770862634L, 1530479509L, 610813999L, 614252854L, 
+1209524576L, 1709473699L, -660354879L, -1347618640L, 1321666510L, 
+-615507143L, -1222151349L, -2121488134L, 926806524L, 1672630847L, 
+963262229L, 1574421548L, -30720766L, 503043549L, 258581719L, 
+1676578750L, 937404920L, 1607699931L, 1754965049L, -666647160L, 
+-1562259146L, -159356047L, -1544238685L, -512084750L, -1785468860L, 
+-641627385L, -1602057507L, -2076535852L, 478614266L, -764934587L, 
+161767071L, -329472986L, -1741811536L, 1706707283L, -455388047L, 
+1247316384L, -1903426242L, -693287863L, -1319038725L, -1677616950L, 
+-923091412L, 980124207L, -1174127899L, -1410850916L, -2038449678L, 
+-1487481747L, -273156697L, 494100430L, -2118238936L, -1174266069L, 
+119752009L, 1297345112L, 938222342L, 36736737L, 437701235L, -1335856414L, 
+301821524L, 1576499031L, 1871776589L, -706838812L, -1172324662L, 
+-1245446347L, 1707996559L, -1331580266L, -199112128L, -244786429L, 
+-9229535L, -1070478320L, -126354450L, -1693635687L, -2013105109L, 
+265089306L, 1154581468L, -922327585L, -1201663563L, -1166917812L, 
+-354151006L, 699823357L, -744367625L, -119695586L, 1531980248L, 
+-988970181L, -1918917415L, 1316464744L, 1868610966L, 286582033L, 
+194053827L, -1373190446L, 969768804L, -1326890329L, -1552421891L, 
+-988799500L, 1991654106L, 1148451877L, 2014196031L, 1273603782L, 
+562850640L, 1762775923L, -613513839L, 1555630016L, 1693675934L, 
+-744670359L, 572845979L, -1165912406L, 109027532L, 2141282703L, 
+2121708997L, 652401020L, -1676842542L, -1573923507L, 1488013319L, 
+-1412192274L, 1394593480L, -1827986997L, 2022577193L, 452625016L, 
+-1124454490L, 1550838209L, 473718355L, 114799874L, 1725658164L, 
+-1819261513L, -1704040019L, -2102678844L, 490761962L, -1153580715L, 
+-715704593L, 171197686L, 808424480L, -1149499933L, 516126337L, 
+-1429896976L, -876052594L, -1876586247L, -821765493L, -1689732422L, 
+-88083012L, 675847935L, -1830677931L, 1758881132L, -2013696574L, 
+-1438806499L, 422368919L, 1630953470L, 716737464L, -1027807333L, 
+601067001L, 659656008L, -434386826L, -1532611151L, 142130147L, 
+918096050L, 1262904580L, -934304185L, 101789981L, 776634260L, 
+977134394L, 2142842757L, 1404599391L, 412759782L, -475906704L, 
+384681619L, -1015783631L, 539649504L, -1830075778L, 1345761545L, 
+1637192507L, 2125277962L, 268870380L, 87400303L, -772292443L, 
+-1967101348L, 1363462706L, 845668653L, -572004377L, -575312114L, 
+1248182504L, -4656405L, -778364023L, -1604860136L, -1043248570L, 
+-539776351L, -1747219149L, -431057758L, -483435628L, -825384425L, 
+1412343309L, -1298742492L, -775012598L, -1689447819L, -1082519089L, 
+-1420322090L, 2082995840L, 832544963L, -1040351647L, 1074198224L, 
+-1336127442L, 1392743897L, 1171024363L, 465378394L, -733346276L, 
+176482079L, 453589877L, -1667702260L, -1048218654L, 984162493L, 
+629182263L, -878741538L, -397687528L, 1434757243L, 1041813017L, 
+-608803160L, 1376445526L, -928423727L, -1063306109L, -604856558L, 
+1673079460L, 542914151L, 322774973L, 2064349492L, -1263404390L, 
+1244281061L, -1411519873L, 1311838140L, -1295110060L, 415105986L, 
+-654924768L, 1121848508L, -1370527152L, -113717278L, 2030057064L, 
+1373751884L, 979140860L, -880398350L, 1126284544L, 1158698868L, 
+-1674469368L, 1270404538L, -1882317360L, -700431380L, -1769480300L, 
+1625304018L, -427165856L, 225645900L, -129532640L, 975115138L, 
+1449716456L, -729615124L, 1403238972L, -1481581710L, 171584112L, 
+-1225258972L, 2028910392L, -1506722662L, 692302544L, 162685116L, 
+796960404L, 1911047810L, 2131877056L, -1788096196L, -779165552L, 
+-1151837662L, -491809272L, -72609524L, 810369692L, -977019374L, 
+2093198720L, -1653494252L, -1023023576L, -2047093446L, 1575012304L, 
+-683081108L, 1973888820L, -315059566L, -1204569760L, -1988345524L, 
+1131945952L, 973066146L, -2133887064L, 1506753420L, -908355908L, 
+38394738L, 1100376304L, 1016453188L, -1596498600L, 1889535034L, 
+1264558960L, -1963236292L, 1302108948L, 468257218L, 152301792L, 
+-762206340L, 1987047120L, -1639414110L, 1260774440L, -1243199220L, 
+1957045180L, -2106053326L, -446898240L, 1804849716L, 1478659016L, 
+-1824488262L, 650293136L, -1527691796L, -590512044L, -1533047150L, 
+521419552L, 816659916L, 1002908640L, -1003072830L, -1010079192L, 
+529653420L, -561237316L, 96936434L, 1963305264L, 1870142628L, 
+552620728L, -360715430L, 2013310352L, 1766564220L, -942121708L, 
+1449314626L, -54574336L, 561617852L, -2097116336L, -1090625246L, 
+-1863938744L, 1540675596L, 1969535068L, 93787346L, 161662976L, 
+1757465428L, -167890456L, 1794533370L, -134289712L, -1891740372L, 
+205117684L, 1746081682L, 1655508064L, 441928972L, 730195680L, 
+1547169122L, -1877851480L, -58709428L, -594884740L, 780733234L, 
+-97300880L, 258383172L, 1908829144L, -1377116038L, 1650087472L, 
+2095831740L, 13154132L, -1167639998L, -705225824L, 204331196L, 
+438563280L, 1334691170L, 1019651048L, -45774900L, 346031868L, 
+-1260425230L, 249592960L, -2083411724L, -1004178296L, -1869695686L, 
+-1389403312L, -314184596L, 2114097300L, 250325330L, -734150944L, 
+287850700L, 1125095584L, 1141578114L, -1037231896L, -764229396L, 
+1880737852L, 275783794L, -1511372688L, 765993508L, 1556906552L, 
+98802202L, -1874100016L, 824624700L, -871207788L, 1069696130L, 
+-1978841152L, -832324292L, -1205408112L, -1405795294L, -105418744L, 
+-1533289332L, -435318756L, 501748882L, -4739968L, 2059240468L, 
+-2081561816L, -1329081286L, 182668496L, 1704580204L, -963295564L, 
+-2040639470L, 515448800L, 1503931340L, 820927968L, -2125800414L, 
+529851688L, -1145366260L, 1181904444L, -2130676494L, 1288759536L, 
+-1482873020L, 1204916312L, 967885370L, 481982704L, -1766206788L, 
+2106866196L, -1490195262L, 1579869792L, 1580758396L, -775031600L, 
+-238459870L, -2141247320L, -1490563700L, -1196731972L, 552146994L, 
+-718765248L, -2141466956L, -778411704L, 404628154L, 974028560L, 
+-431726356L, -1795135404L, 335906578L, 595698080L, -259250228L, 
+-1377468576L, 1030315202L, 1543269928L, 1143151020L, 237093692L, 
+-853257358L, 826462000L, 1288675364L, -1474171336L, 183407322L, 
+-2044282992L, -480250628L, -572506732L, -1056033982L, -237784646L, 
+-372875272L, -1028678751L, -1308289709L, -313766796L, -434790910L, 
+599765143L, 1314865761L, -1397482842L, 1182974628L, 457115477L, 
+1665928191L, -1656907112L, -1817837642L, -1327811517L, -1678021243L, 
+446477858L, -1861653232L, -953074503L, -1358298773L, -598855588L, 
+-653034102L, -673150593L, 2002392265L, 1733585246L, 1510328844L, 
+1620192733L, 1508160743L, 2048463120L, 1799827502L, 512411355L, 
+1220083645L, -1776133846L, 2145947080L, -1340435727L, 593116259L, 
+1873627236L, -600554606L, 2045593703L, -1743251407L, 1204447606L, 
+1388435092L, 2127928485L, 733757871L, 954505832L, -846798266L, 
+375474163L, 422983509L, 882633010L, 648379648L, 94043625L, -353941413L, 
+108321452L, 149701818L, -1992440209L, -1157508103L, -2015020402L, 
+-1569342628L, -605128755L, 211646263L, -942545472L, -956233058L, 
+-914889877L, 1250327277L, 921628506L, 1035346968L, -1105518207L, 
+1847285555L, 299765076L, 1948862306L, 1436933111L, 932979777L, 
+1661178054L, 1278123524L, 799726005L, -1983551841L, -1938217224L, 
+77302486L, 1813667683L, 750200613L, 1564302530L, -121415248L, 
+1196306905L, 707051339L, -1151601220L, 558900714L, 1502093855L, 
+-841938775L, -1036320706L, -1116344020L, -1649378435L, 698388935L, 
+-1151695696L, 2001785550L, 1643481083L, 1820053597L, -1705560182L, 
+-1713080408L, -528499439L, -1354152957L, -116330748L, -710180046L, 
+959603079L, -1072396335L, -467064490L, 492439348L, -1245697467L, 
+61200015L, -217595896L, -40082394L, -115933997L, -974922187L, 
+1693074L, 1436150112L, -394555191L, 248488955L, -1093434420L, 
+26082906L, -1354210481L, -558859751L, 1223817262L, -360712644L, 
+-795276371L, -2050251689L, -567258720L, 1307732734L, 1849395659L, 
+1270247373L, -1359338758L, 876665144L, 1311269601L, -1003952749L, 
+-77640268L, 1269845698L, -2054119721L, 741003041L, 535783142L, 
+96116708L, 1224544021L, 1324640063L, 731443928L, -242321674L, 
+571040003L, -1544199611L, 1140372066L, 916517328L, -1646309639L, 
+-838153173L, -1977168996L, 681370570L, -2134139713L, -69255671L, 
+1387919134L, 789954252L, -57803107L, -1078428889L, -2023418544L, 
+410016750L, -523541349L, -931950851L, -471411222L, -823531896L, 
+-716705743L, -6305117L, 1938240164L, -141941934L, 346581671L, 
+-444360975L, 277083702L, -252401911L)
 .txtline <-
 function(txt, width, space="", ind="") {
   paste(
